#!/usr/bin/env python
"""
This class has a collection of various tools that are used with
sosreports/sysreports.

@author    :  Shane Bradley
@contact   :  sbradley@redhat.com
@version   :  2.03
@copyright :  GPLv2
"""
import os
import os.path
import string
import re
import logging

import sx

def isFilesIdentical(pathToBaseFile, pathToFilesList) :
    """
    This function uses md5sum to verify that all files in array have
    same md5sum as the base file. If all files have same md5sum then
    True is returned.
    
    If the file list does not contain 2 or more files then False is
    returned.

    @return: True if cluster.confs are same on ClusterNode's.
    @rtype: Boolean
    
    @param pathToBaseFile: The path to the base file that all files
    will be compared against.
    @type pathToBaseFile: String
    @param pathToFilesList: A list of files that will be
    compared. This can include the base file.
    @type pathToFilesList: String
    """
    hashlibExists = True
    try:
        # python 2.6
        import hashlib
    except:
        # python 2.4
        import md5
        hashlibExists = False
            
    # If array does not contain more than one file then nothing is
    # there to compare, so False is returned.
    if (not len(pathToFilesList) > 1) :
        message = "There are not enough cluster.conf files to compare mdsum's. There must be 2 or more cluster.conf files."
        logging.getLogger(sx.MAIN_LOGGER_NAME).error(message)                                                                                 
        return False
    baseMD5Sum = ""
    try:
        fin = open(pathToBaseFile, "r")
        data = string.rstrip(fin.read())
        fin.close()
        if hashlibExists: 
            md5sum = hashlib.md5() 
            md5sum.update(data)
            baseMD5Sum = md5sum.digest()
        else:
            md5sum = md5.new()
            md5sum.update(data)
            baseMD5Sum = md5sum.hexdigest()
            if (not len(baseMD5Sum) > 0) :    
                message = "The base file's md5sum was an empty string: \n\t%s" %(pathToBaseFile)
                logging.getLogger(sx.MAIN_LOGGER_NAME).error(message)                                                                                 
                return False
    except (IOError, os.error):
        message = "An i/o error occured in getting the base md5sum for file: \n\t%s" %(pathToBaseFile)
        logging.getLogger(sx.MAIN_LOGGER_NAME).error(message)                                                                                 
        return False
        
    # Now do the compare on files against the base(base will be
    # compared as well)
    for filePath in pathToFilesList:
        try:
            fin = open(filePath, "r")
            data = string.rstrip(fin.read())
            fin.close()
            currentMD5Sum = ""
            if hashlibExists: 
                md5sum = hashlib.md5() 
                md5sum.update(data)
                currentMD5Sum = md5sum.digest()
            else:
                md5sum = md5.new()
                md5sum.update(data)
                currentMD5Sum = md5sum.hexdigest()
            if (not currentMD5Sum  == baseMD5Sum) :
                return False
        except (IOError, os.error):
            message = "An i/o error occured in getting the base md5sum for file: \n\t%s" %(baseFilePath)
            logging.getLogger(sx.MAIN_LOGGER_NAME).error(message)   
            return False
    return True
    
